{
Copyright (C) 2000, 2001 Free Software Foundation, Inc.

Author: Eike Lange <eike.lange@uni-essen.de>

mysql.pas, a unit for MySql

This unit implements a set of Funktions for accessing 
MySql. 

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation, version 2.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA.
}

{
  ==============================
	PLEASE READ THE README
  ==============================
}

unit mysql;

interface

const 

	{ Error-Numbers from errmsg.h }
	CR_MIN_ERROR = 2000;
	CR_MAX_ERROR = 2999;
	CLIENT_ERRMAP = 2;
	CR_UNKNOWN_ERROR = 2000;
	CR_SOCKET_CREATE_ERROR = 2001;
	CR_CONNECTION_ERROR = 2002;
	CR_CONN_HOST_ERROR = 2003;
	CR_IPSOCK_ERROR = 2004;
	CR_UNKNOWN_HOST = 2005;
	CR_SERVER_GONE_ERROR = 2006;
	CR_VERSION_ERROR = 2007;
	CR_OUT_OF_MEMORY = 2008;
	CR_WRONG_HOST_INFO = 2009;
	CR_LOCALHOST_CONNECTION = 2010;
	CR_TCP_CONNECTION = 2011;
	CR_SERVER_HANDSHAKE_ERR = 2012;
	CR_SERVER_LOST = 2013;
	CR_COMMANDS_OUT_OF_SYNC = 2014;
	CR_NAMEDPIPE_CONNECTION = 2015;
	CR_NAMEDPIPEWAIT_ERROR = 2016;
	CR_NAMEDPIPEOPEN_ERROR = 2017;
	CR_NAMEDPIPESETSTATE_ERROR = 2018;
	
	ER_HASHCHK = 1000;
	ER_NISAMCHK = 1001;
	ER_NO = 1002;
	ER_YES = 1003;
	ER_CANT_CREATE_FILE = 1004;
	ER_CANT_CREATE_TABLE = 1005;
	ER_CANT_CREATE_DB = 1006;
	ER_DB_CREATE_EXISTS = 1007;
	ER_DB_DROP_EXISTS = 1008;
	ER_DB_DROP_DELETE = 1009;
	ER_DB_DROP_RMDIR = 1010;
	ER_CANT_DELETE_FILE = 1011;
	ER_CANT_FIND_SYSTEM_REC = 1012;
	ER_CANT_GET_STAT = 1013;
	ER_CANT_GET_WD = 1014;
	ER_CANT_LOCK = 1015;
	ER_CANT_OPEN_FILE = 1016;
	ER_FILE_NOT_FOUND = 1017;
	ER_CANT_READ_DIR = 1018;
	ER_CANT_SET_WD = 1019;
	ER_CHECKREAD = 1020;
	ER_DISK_FULL = 1021;
	ER_DUP_KEY = 1022;
	ER_ERROR_ON_CLOSE = 1023;
	ER_ERROR_ON_READ = 1024;
	ER_ERROR_ON_RENAME = 1025;
	ER_ERROR_ON_WRITE = 1026;
	ER_FILE_USED = 1027;
	ER_FILSORT_ABORT = 1028;
	ER_FORM_NOT_FOUND = 1029;
	ER_GET_ERRNO = 1030;
	ER_ILLEGAL_HA = 1031;
	ER_KEY_NOT_FOUND = 1032;
	ER_NOT_FORM_FILE = 1033;
	ER_NOT_KEYFILE = 1034;
	ER_OLD_KEYFILE = 1035;
	ER_OPEN_AS_READONLY = 1036;
	ER_OUTOFMEMORY = 1037;
	ER_OUT_OF_SORTMEMORY = 1038;
	ER_UNEXPECTED_EOF = 1039;
	ER_CON_COUNT_ERROR = 1040;
	ER_OUT_OF_RESOURCES = 1041;
	ER_BAD_HOST_ERROR = 1042;
	ER_HANDSHAKE_ERROR = 1043;
	ER_DBACCESS_DENIED_ERROR = 1044;
	ER_ACCESS_DENIED_ERROR = 1045;
	ER_NO_DB_ERROR = 1046;
	ER_UNKNOWN_COM_ERROR = 1047;
	ER_BAD_NULL_ERROR = 1048;
	ER_BAD_DB_ERROR = 1049;
	ER_TABLE_EXISTS_ERROR = 1050;
	ER_BAD_TABLE_ERROR = 1051;
	ER_NON_UNIQ_ERROR = 1052;
	ER_SERVER_SHUTDOWN = 1053;
	ER_BAD_FIELD_ERROR = 1054;
	ER_WRONG_FIELD_WITH_GROUP = 1055;
	ER_WRONG_GROUP_FIELD = 1056;
	ER_WRONG_SUM_SELECT = 1057;
	ER_WRONG_VALUE_COUNT = 1058;
	ER_TOO_LONG_IDENT = 1059;
	ER_DUP_FIELDNAME = 1060;
	ER_DUP_KEYNAME = 1061;
	ER_DUP_ENTRY = 1062;
	ER_WRONG_FIELD_SPEC = 1063;
	ER_PARSE_ERROR = 1064;
	ER_EMPTY_QUERY = 1065;
	ER_NONUNIQ_TABLE = 1066;
	ER_INVALID_DEFAULT = 1067;
	ER_MULTIPLE_PRI_KEY = 1068;
	ER_TOO_MANY_KEYS = 1069;
	ER_TOO_MANY_KEY_PARTS = 1070;
	ER_TOO_LONG_KEY = 1071;
	ER_KEY_COLUMN_DOES_NOT_EXITS = 1072;
	ER_BLOB_USED_AS_KEY = 1073;
	ER_TOO_BIG_FIELDLENGTH = 1074;
	ER_WRONG_AUTO_KEY = 1075;
	ER_READY = 1076;
	ER_NORMAL_SHUTDOWN = 1077;
	ER_GOT_SIGNAL = 1078;
	ER_SHUTDOWN_COMPLETE = 1079;
	ER_FORCING_CLOSE = 1080;
	ER_IPSOCK_ERROR = 1081;
	ER_NO_SUCH_INDEX = 1082;
	ER_WRONG_FIELD_TERMINATORS = 1083;
	ER_BLOBS_AND_NO_TERMINATED = 1084;
	ER_TEXTFILE_NOT_READABLE = 1085;
	ER_FILE_EXISTS_ERROR = 1086;
	ER_LOAD_INFO = 1087;
	ER_ALTER_INFO = 1088;
	ER_WRONG_SUB_KEY = 1089;
	ER_CANT_REMOVE_ALL_FIELDS = 1090;
	ER_CANT_DROP_FIELD_OR_KEY = 1091;
	ER_INSERT_INFO = 1092;
	ER_INSERT_TABLE_USED = 1093;
	ER_NO_SUCH_THREAD = 1094;
	ER_KILL_DENIED_ERROR = 1095;
	ER_NO_TABLES_USED = 1096;
	ER_TOO_BIG_SET = 1097;
	ER_NO_UNIQUE_LOGFILE = 1098;
	ER_TABLE_NOT_LOCKED_FOR_WRITE = 1099;
	ER_TABLE_NOT_LOCKED = 1100;
	ER_BLOB_CANT_HAVE_DEFAULT = 1101;
	ER_WRONG_DB_NAME = 1102;
	ER_WRONG_TABLE_NAME = 1103;
	ER_TOO_BIG_SELECT = 1104;
	ER_UNKNOWN_ERROR = 1105;
	ER_UNKNOWN_PROCEDURE = 1106;
	ER_WRONG_PARAMCOUNT_TO_PROCEDURE = 1107;
	ER_WRONG_PARAMETERS_TO_PROCEDURE = 1108;
	ER_UNKNOWN_TABLE = 1109;
	ER_FIELD_SPECIFIED_TWICE = 1110;
	ER_INVALID_GROUP_FUNC_USE = 1111;
	ER_UNSUPPORTED_EXTENSION = 1112;
	ER_TABLE_MUST_HAVE_COLUMNS = 1113;
	ER_RECORD_FILE_FULL = 1114;
	ER_UNKNOWN_CHARACTER_SET = 1115;
	ER_TOO_MANY_TABLES = 1116;
	ER_TOO_MANY_FIELDS = 1117;
	ER_TOO_BIG_ROWSIZE = 1118;
	ER_STACK_OVERRUN = 1119;
	ER_WRONG_OUTER_JOIN = 1120;
	ER_NULL_COLUMN_IN_INDEX = 1121;
	ER_CANT_FIND_UDF = 1122;
	ER_CANT_INITIALIZE_UDF = 1123;
	ER_UDF_NO_PATHS = 1124;
	ER_UDF_EXISTS = 1125;
	ER_CANT_OPEN_LIBRARY = 1126;
	ER_CANT_FIND_DL_ENTRY = 1127;
	ER_FUNCTION_NOT_DEFINED = 1128;
	ER_HOST_IS_BLOCKED = 1129;
	ER_HOST_NOT_PRIVILEGED = 1130;
	ER_PASSWORD_ANONYMOUS_USER = 1131;
	ER_PASSWORD_NOT_ALLOWED = 1132;
	ER_PASSWORD_NO_MATCH = 1133;
	ER_UPDATE_INFO = 1134;
	ER_CANT_CREATE_THREAD = 1135;
	ER_WRONG_VALUE_COUNT_ON_ROW = 1136;
	ER_CANT_REOPEN_TABLE = 1137;
	ER_INVALID_USE_OF_NULL = 1138;
	ER_REGEXP_ERROR = 1139;
	ER_MIX_OF_GROUP_FUNC_AND_FIELDS = 1140;
	ER_NONEXISTING_GRANT = 1141;
	ER_TABLEACCESS_DENIED_ERROR = 1142;
	ER_COLUMNACCESS_DENIED_ERROR = 1143;
	ER_ILLEGAL_GRANT_FOR_TABLE = 1144;
	ER_GRANT_WRONG_HOST_OR_USER = 1145;
	ER_NO_SUCH_TABLE = 1146;
	ER_NONEXISTING_TABLE_GRANT = 1147;
	ER_NOT_ALLOWED_COMMAND = 1148;
	ER_SYNTAX_ERROR = 1149;
	ER_DELAYED_CANT_CHANGE_LOCK = 1150;
	ER_TOO_MANY_DELAYED_THREADS = 1151;
	ER_ABORTING_CONNECTION = 1152;
	ER_NET_PACKET_TOO_LARGE = 1153;
	ER_NET_READ_ERROR_FROM_PIPE = 1154;
	ER_NET_FCNTL_ERROR = 1155;
	ER_NET_PACKETS_OUT_OF_ORDER = 1156;
	ER_NET_UNCOMPRESS_ERROR = 1157;
	ER_NET_READ_ERROR = 1158;
	ER_NET_READ_INTERRUPTED = 1159;
	ER_NET_ERROR_ON_WRITE = 1160;
	ER_NET_WRITE_INTERRUPTED = 1161;
	ER_ERROR_MESSAGES = 162;

{ field_types from mysql_com.h }
	FIELD_TYPE_DECIMAL			= 0;
	FIELD_TYPE_TINY					= 1;
	FIELD_TYPE_SHORT				= 2;
	FIELD_TYPE_LONG					= 3;
	FIELD_TYPE_FLOAT				= 4;
	FIELD_TYPE_DOUBLE				= 5;
	FIELD_TYPE_NULL					= 6;
	FIELD_TYPE_TIMESTAMP		= 7;
	FIELD_TYPE_LONGLONG			= 8;
	FIELD_TYPE_INT24				= 9;
	FIELD_TYPE_DATE					= 10;
  FIELD_TYPE_TIME					= 11;
	FIELD_TYPE_DATETIME			= 12;
	FIELD_TYPE_YEAR					= 13;
	FIELD_TYPE_NEWDATE			= 14;
	FIELD_TYPE_ENUM					= 247;
	FIELD_TYPE_SET					= 248;
	FIELD_TYPE_TINY_BLOB		= 249;
	FIELD_TYPE_MEDIUM_BLOB	= 250;
	FIELD_TYPE_LONG_BLOB		= 251;
	FIELD_TYPE_BLOB					= 252;
 	FIELD_TYPE_VAR_STRING		= 253;
 	FIELD_TYPE_STRING				= 254;

	{ Options from mysql.h for MysqlOptions }
	MYSQL_OPT_CONNECT_TIMEOUT = 0;
	MYSQL_OPT_COMPRESS        = 1;
	MYSQL_OPT_NAMED_PIPE      = 2;
	MYSQL_INIT_COMMAND        = 3;
	MYSQL_READ_DEFAULT_FILE   = 4;
	MYSQL_READ_DEFAULT_GROUP  = 5;
	MYSQL_SET_CHARSET_DIR     = 6;
	MYSQL_SET_CHARSET_NAME    = 7;

type
  PMysql = Pointer;						{ Pointer to MYSQL-Structure }
  PMysqlRes = Pointer;				{ Pointer to MYSQL_RES-Structure }
  ShortString = String (32);
  NormalString = String (255);
  CMysqlRow = array [0..High(Cardinal) div SizeOf(CString)-1] of CString;
  MysqlRow = ^CMysqlRow;

  PMysqlField=^MysqlField;
  MysqlField=record
	  name, table, def : CString;
  	{ Not the same enum-Numbers like C !!! so I think, it would be OK,
	  	to change the name from "type" to 'typ'
		  because "type" is a keyword in Pascal
  	}
	  Typ : Integer; {See FIELD_TYPE_* - Constants above }
  	length, max_length, flags, decimals : Cardinal
  end;

{ ShortCard is the biggest type I can use. }
MysqlFieldArray = array [0..High(ShortCard) div SizeOf(MysqlField)-1] of MysqlField;

MYSQL_FIELD_OFFSET = Cardinal;

PFLA = ^FLA;
FLA = array [0..High(MedCard) div SizeOf(MedCard)-1] of MedCard;

{
Its just a pointer, because the contents are given by MysqlFetchRow,
its just for MysqlRowSeek and MysqlRowTell
}
MYSQL_ROW_OFFSET = Pointer;


{ --------------------------------------------------------}
{ Functions }
{ --------------------------------------------------------}



{ Gives out the number of affected rows, you must call something
like MysqlStoreResult, if you use a SELECT-query}
function MysqlAffectedRows(MysqlHandle : PMysql) : LongInt;
asmname '_p_mysql_affected_rows';

{ Changes the user and database of a given connection. (See query1.pas) }
function MysqlChangeUser(MysqlHandle : PMysql; user, password, database : NormalString) : Boolean;

{ returns the name of the character-set }
function MysqlCharacterSetName(MysqlHandle : PMysql) : NormalString;

procedure MysqlClose(MysqlHandle : PMysql);
asmname '_p_mysql_close';

{ Creates a Mysql-Database }
function MysqlCreateDb(MysqlHandle : PMysql; dbname : CString) : Boolean;

{ Offset is from 0 to NumRows-1, else returns memory-error }
procedure MysqlDataSeek(MysqlHandle : PMysql; Offset : Cardinal);
asmname '_p_mysql_data_seek';

{ You may need FredFish: "Debug Library" to use this Procedure. See
chapters G1/G2 (Debugging Mysql client and server) in Mysql
Reference Manual for Details (Version 3.23.42) }
procedure MysqlDebug(Debug : CString);
asmname '_p_mysql_debug';
function MysqlDropDb(MysqlHandle : PMysql; dbname : CString) : Boolean;
function MysqlDumpDebugInfo(MysqlHandle : PMysql) : Boolean;


function MysqlErrNo(MysqlHandle : PMysql) : Cardinal;
asmname '_p_mysql_errno';
function MysqlError(MysqlHandle : PMysql) : NormalString;
function MysqlEscapeString(ToString : CString; FromString : CString; length : Cardinal) : Cardinal;
asmname '_p_mysql_escape_string';


function MysqlFetchField(MysqlRes : PMysqlRes) : PMysqlFIELD;
asmname '_p_mysql_fetch_field';

function MysqlFetchFieldDirect(MysqlRes : PMysqlRes; fieldnr : Cardinal) : PMysqlFIELD;
asmname '_p_mysql_fetch_field_direct';

{ Fetches all fields and saves them in MysqlFieldArray. (See FetchFields.pas) }
function MysqlFetchFields(MysqlRes : PMysqlRes) : MysqlFieldArray;

{ Be sure  to call MysqlFetchLengths AFTER MysqlFetchRow }
function MysqlFetchLengths(MysqlRes : PMysqlRes) : PFLA;
asmname '_p_mysql_fetch_lengths';

function MysqlFetchRow(MysqlRes : PMysqlRes) : MYSQLROW;
asmname '_p_mysql_fetch_row';

{ returns the number of columns for the last query }
function MysqlFieldCount(MysqlHandle : PMysql) : Cardinal;
asmname '_p_mysql_field_count';

function MysqlFieldSeek(MysqlRes : PMysqlRes; Offset : MYSQL_FIELD_OFFSET) : MYSQL_FIELD_OFFSET;
asmname '_p_mysql_field_seek';

function MysqlFieldTell(MysqlRes : PMysqlRes) : MYSQL_FIELD_OFFSET;
asmname '_p_mysql_field_tell';

procedure MysqlFreeResult(MysqlRes : PMysqlRes);
asmname '_p_mysql_free_result';


function MysqlGetClientInfo: NormalString;
function MysqlGetHostInfo(MysqlHandle : PMysql): NormalString;
function MysqlGetProtoInfo(MysqlHandle : PMysql) : Cardinal;
asmname '_p_mysql_get_proto_info';
{ Prints Out Version Information about mysql }
function MysqlGetServerInfo(MysqlHandle : PMysql) : SHORTSTRING; 

function MysqlInfo(MysqlHandle : PMysql) : NormalString;
{ Initializes MySQL-Api. Must be first API-Function }
function MysqlInit(MysqlHandle:PMysql) : PMysql; 
asmname '_p_mysql_init';
{ Returns the ID for an auto_increment value after SQL-INSERT }
function MysqlInsertId(MysqlHandle:PMysql) : LongInt;
asmname '_p_mysql_insert_id';

{ Kills the Server, Returns true on success }
function MysqlKill(MysqlHandle : PMysql; pid : Integer) : Boolean;

{ Returns a Handle points to all the DBs which MySQL handles }
function MysqlListDbs(MysqlHandle : PMysql; wild : CString) : PMysqlRes;
asmname '_p_mysql_list_dbs';

{ Returns a Handle points to all the fields of a given table }
function MysqlListFields(MysqlHandle : PMysql; table : CString; wild : CString) : PMysqlRes;
asmname '_p_mysql_list_fields';

function MysqlListProcesses(MysqlHandle : PMysql) : PMysqlRes;
asmname '_p_mysql_list_processes';

{ Returns a Handle points to all the DBs which MySQL handles }
function MysqlListTables(MysqlHandle : PMysql; wild : CString) : PMysqlRes;
asmname '_p_mysql_list_tables';

{ Gives out the number of Fiels }
function MysqlNumFields(MysqlRes : PMysqlRes) : Cardinal;
asmname '_p_mysql_num_fields';

{ Gives out the number of affected rows }
function MysqlNumRows(MysqlRes : PMysqlRes) : LongInt;
asmname '_p_mysql_num_rows';

{ Sets extra-connect-options. option is one of the following:
MYSQL_OPT_CONNECT_TIMEOUT, MYSQL_OPT_COMPRESS, MYSQL_OPT_NAMED_PIPE,
MYSQL_INIT_COMMAND, MYSQL_READ_DEFAULT_FILE, MYSQL_READ_DEFAULT_GROUP,
MYSQL_SET_CHARSET_DIR, MYSQL_SET_CHARSET_NAME}
function MysqlOptions(MysqlHandle : PMysql; option : Integer; arg : CString) : Boolean;

{ Returns True, if Server is alive }
function MysqlPing(MysqlHandle : PMysql) : Boolean;

{ Executes a Query like "SELECT * FROM test", returns true on success}
function MysqlQuery(MysqlHandle : PMysql; query : CString) : Boolean;

{ Connects to mysql. You *must* call MysqlInit first! You need at least
the name of the Database }
function MysqlRealConnect(
	MysqlHandle : PMysql;
	host: CString;
	user: CString;
	passwd: CString;
	db : CString;
	port : Cardinal;
	socket : CString;
	client_flag : Cardinal) : PMysql;
asmname '_p_mysql_real_connect';

{ Connects to mysql. You *must* call MysqlInit first! You need at least
the name of the Database }
function MysqlRealConnect2(
	MysqlHandle : PMysql;
	host: CString;
	user: CString;
	passwd: CString;
	db : CString) : PMysql;
asmname '_p_mysql_real_connect2';

function MysqlRealEscapeString(MysqlHandle : PMysql; ToString : CString; FromString : CString; length : Cardinal) : Cardinal;
asmname '_p_mysql_real_escape_string';

function MysqlRealQuery(MysqlHandle : PMysql; query : CString; length:Cardinal):Boolean;

function MysqlRowSeek(MysqlRes : PMysqlRes; offset : MYSQL_ROW_OFFSET) : MYSQL_ROW_OFFSET;
asmname '_p_mysql_row_seek';

function MysqlRowTell(MysqlRes : PMysqlRes) : MYSQL_ROW_OFFSET;
asmname '_p_mysql_row_tell';

function MysqlSelectDb(MysqlHandle : PMysql; db : CString) : Boolean;
function MysqlShutdown(MysqlHandle : PMysql) : Boolean;
function MysqlStat(MysqlHandle : PMysql) : NormalString;
function MysqlStoreResult(MysqlHandle : PMysql) : PMysqlRes;
asmname '_p_mysql_store_result';

function MysqlThreadId(MysqlHandle : PMysql) : Cardinal;
asmname '_p_mysql_thread_id';

function MysqlUseResult(MysqlHandle : PMysql) : PMysqlRes;
asmname '_p_mysql_use_result';


{ ================================================================== }

implementation
{$L mysqlclient,mysqlc.c}


function CMysqlChangeUser(MysqlHandle : PMysql; u, p, d : CString) : Byte;
asmname '_p_mysql_change_user';

function CMysqlCharacterSetName(MysqlHandle : PMysql) : CString;
asmname '_p_mysql_character_set_name';

{ The original Mysql_Create_Db - C-Function return 0 on success. 
Pascal Style is true/false, I think }
function CMysqlCreateDb(MysqlRes : PMysqlRes; dbname : CString) : Integer;
asmname '_p_mysql_create_db';

{ The original Mysql_Drop_Db - C-function return 0 on success. 
Pascal Style is true/false, I think }
function CMysqlDropDb(MysqlRes : PMysqlRes; dbname : CString) : Integer;
asmname '_p_mysql_drop_db';

{ The original Mysql_Dump_debug_info- C-function return 0 on success. 
Pascal Style is true/false, I think }
function CMysqlDumpDebugInfo(MysqlRes : PMysqlRes) : Integer;
asmname '_p_mysql_dump_debug_info';

{ I don't want to return a CString so ...}
function CMysqlError(MysqlHandle : PMysql) : CString;
asmname '_p_mysql_error';

{ I don't want to return a CString so ...}
function CMysqlGetClientInfo : CString; 
asmname '_p_mysql_get_client_info';

{ I don't want to return a CString so ...}
function CMysqlGetHostInfo(MysqlHandle : PMysql) : CString; 
asmname '_p_mysql_get_host_info';

{ I don't want to return a CString so ...}
function CMysqlGetServerInfo(MysqlHandle : PMysql) : CString; 
asmname '_p_mysql_get_server_info';

function CMysqlInfo(MysqlHandle : PMysql) : CString;
asmname '_p_mysql_info';

function CMysqlKill(MysqlHandle : PMysql; pid : Integer) : Integer;
asmname '_p_mysql_kill';

function CMysqlOptions(MysqlHandle : PMysql; opt : Integer; arg : CString) : Integer;
asmname '_p_mysql_options';

function CMysqlPing(MysqlHandle : PMysql) : Integer;
asmname '_p_mysql_ping';

function CMysqlQuery(MysqlHandle : PMysql; query : CString) : Integer;
asmname '_p_mysql_query';

function CMysqlRealQuery(MysqlHandle : PMysql; query : CString; length:Cardinal):Integer;
asmname '_p_mysql_real_query';

function CMysqlSelectDb(MysqlHandle : PMysql; db : CString) : Integer;
asmname '_p_mysql_select_db';

function CMysqlShutdown(MysqlHandle : PMysql) : Integer;
asmname '_p_mysql_shutdown';

function CMysqlStat(MysqlHandle : PMysql) : CString;
asmname '_p_mysql_stat';





function MysqlChangeUser(MysqlHandle : PMysql; user, password, database : NormalString) : Boolean;
begin
	if CMysqlChangeUser(MysqlHandle,  user, password, database) = 0 then
		MysqlChangeUser := True
	else 	MysqlChangeUser := False	
end;

function MysqlCharacterSetName(MysqlHandle : PMysql) : NormalString;
begin
  MysqlCharacterSetName:= CString2String (CMysqlCharacterSetName(MysqlHandle))
end;

function MysqlCreateDb(MysqlHandle : PMysql; dbname : CString) : Boolean;
begin
	if CMysqlCreateDb(MysqlHandle, dbname) = 0 then
		MysqlCreateDb:=True
	else
		MysqlCreateDb:=False
end;

function MysqlDropDb(MysqlHandle : PMysql; dbname : CString) : Boolean;
begin
	if CMysqlDropDb(MysqlHandle, dbname) = 0 then
		MysqlDropDb:=True
	else
		MysqlDropDb:=False
end;

function MysqlDumpDebugInfo(MysqlHandle : PMysql) : Boolean;
begin
	if CMysqlDumpDebugInfo(MysqlHandle) = 0 then
		MysqlDumpDebugInfo:=True
	else
		MysqlDumpDebugInfo:=False
end;

function MysqlError(MysqlHandle : PMysql) : NormalString;
begin
	MysqlError:=CString2String(CMysqlError(MysqlHandle))
end;

{ --------- Changed in 2000-11-26
function MysqlFetchFields(MysqlRes : PMysqlRes) : MysqlFieldArray;
var
	i : Cardinal;
	ffa : MysqlFieldArray;
begin
	for i := 0 To (MysqlNumFields(MysqlRes) - 1) do
		ffa[i] := MysqlFetchField(MysqlRes)^;
	MysqlFetchFields := ffa
end;
---------- }
function MysqlFetchFields(MysqlRes : PMysqlRes) = fa : MysqlFieldArray;
var
	i : Cardinal;
begin
	for i := 0 To (MysqlNumFields(MysqlRes) - 1) do
		fa[i] := MysqlFetchField(MysqlRes)^;
end;

function MysqlGetClientInfo: NormalString;
begin
	MysqlGetClientInfo:=CString2String(CMysqlGetClientInfo);
end;

function MysqlGetHostInfo(MysqlHandle : PMysql) : NormalString;
begin
	MysqlGetHostInfo:=CString2String(CMysqlGetHostInfo(MysqlHandle));
end;


function MysqlGetServerInfo(MysqlHandle : PMysql) : ShortString; 
begin
	MysqlGetServerInfo:=CString2String(CMysqlGetServerInfo(MysqlHandle))
end;

function MysqlInfo(MysqlHandle : PMysql) : NormalString;
begin
	MysqlInfo:=CString2String(CMysqlInfo(MysqlHandle));
end;

function MysqlKill(MysqlHandle : PMysql; pid : Integer) : Boolean;
begin
	if CMysqlKill(MysqlHandle, pid) = 0 then MysqlKill:=true
	else MysqlKill:=False
end;

function MysqlOptions(MysqlHandle : PMysql; option : Integer; arg : CString) : Boolean;
begin
	if CMysqlOptions(MysqlHandle, option, arg) = 0 then MysqlOptions := True
	else MysqlOptions := False
end;

function MysqlPing(MysqlHandle : PMysql) : Boolean;
begin
	if CMysqlPing(MysqlHandle) = 0 then MysqlPing:=true
	else MysqlPing:=false
end;

function MysqlQuery(MysqlHandle : PMysql; query : CString) : Boolean;
begin	
	if CMysqlQuery(MysqlHandle, query) = 0 then MysqlQuery := True
	else MysqlQuery := False
end;

function MysqlRealQuery(MysqlHandle : PMysql; query : CString; length:Cardinal):Boolean;
begin
	if CMysqlRealQuery(MysqlHandle, query, length) = 0 then
		MysqlRealQuery:=true
	else MysqlRealQuery:=false
end;

function MysqlSelectDb(MysqlHandle : PMysql; db : CString) : Boolean;
begin
	if CMysqlSelectDb(MysqlHandle, db) = 0 then
		MysqlSelectDb:=true
	else MysqlSelectDb:=false
end;

function MysqlShutdown(MysqlHandle : PMysql) : Boolean;
begin
	if CMysqlShutdown(MysqlHandle) = 0 then
		MysqlShutdown:=true
	else MysqlShutdown:=false
end;

function MysqlStat(MysqlHandle : PMysql) : NormalString;
begin
	MysqlStat:=CString2String(CMysqlStat(MysqlHandle));
end;

begin
end.

