/*
Copyright (C) 2000 Eike Lange
 
Author: Eike Lange <eike.lange@uni-essen.de>

Support routine for mysql.pas, a unit for accessing MySQL

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation, version 2.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA.
*/
#include <mysql.h>
#include <stdio.h>

/* Deprecated in Mysql 3.22.21
- mysql_connect
- mysql_eof
- mysql_reload
- Compiler-Switch : OLD_MYSQL_VERSION see README for Details
*/

/* Not implemented
- mysql_refresh (no documentation available)
- mysql_odbc_escape_string (no documentation available)
- myodbc_remove_escape (no documentation available)
- mysql_thread_safe (no documentation available)
- mysql_fetch_fields (Found a better way to implement this)
*/

/* ********** Prototypes ********** */
/* unsigned int _p_myodbc_remove_escape(MYSQL *m, char *name); */

long long	_p_mysql_affected_rows(MYSQL *m);

void          _p_mysql_close(MYSQL *m);
unsigned char _p_mysql_change_user(MYSQL *m, const char *user, const char *passwd, const char *db);
const char*   _p_mysql_character_set_name(MYSQL *m);
int           _p_mysql_create_db(MYSQL *m, const char *db);

void					_p_mysql_data_seek(MYSQL_RES *res, unsigned int offset);
void					_p_mysql_debug(char *debug);
int						_p_mysql_drop_db(MYSQL *m, const char *db);
int						_p_mysql_dump_debug_info(MYSQL *m);


unsigned int	_p_mysql_errno(MYSQL *m);
char * 				_p_mysql_error(MYSQL *m);
unsigned int	_p_mysql_escape_string(char *to, const char *from, unsigned int length);

MYSQL_FIELD *		_p_mysql_fetch_field(MYSQL_RES *res);
MYSQL_FIELD *		_p_mysql_fetch_field_direct(MYSQL_RES *res, unsigned int fieldnr);
/* MYSQL_FIELD *		_p_mysql_fetch_fields(MYSQL_RES *res); */
unsigned long *	_p_mysql_fetch_lengths(MYSQL_RES *res);
MYSQL_ROW				_p_mysql_fetch_row(MYSQL_RES *res);

unsigned int				_p_mysql_field_count(MYSQL *m);
MYSQL_FIELD_OFFSET	_p_mysql_field_seek(MYSQL_RES *res, MYSQL_FIELD_OFFSET offset);
MYSQL_FIELD_OFFSET	_p_mysql_field_tell(MYSQL_RES *res);
void 								_p_mysql_free_result(MYSQL_RES *res);

char *				_p_mysql_get_client_info(void);
char *				_p_mysql_get_host_info(MYSQL *m);
unsigned int	_p_mysql_get_proto_info(MYSQL *m);
char * 				_p_mysql_get_server_info(MYSQL *m);

char * 				_p_mysql_info(MYSQL *m);
MYSQL *				_p_mysql_init(MYSQL *m);
long long			_p_mysql_insert_id(MYSQL *m);

int						_p_mysql_kill(MYSQL *m, unsigned long pid);

MYSQL_RES * 	_p_mysql_list_dbs(MYSQL *m, const char *wild);
MYSQL_RES *		_p_mysql_list_fields(MYSQL *m, const char *table,
			const char *wild);
MYSQL_RES *		_p_mysql_list_processes(MYSQL *m);
MYSQL_RES * 	_p_mysql_list_tables(MYSQL *m, const char *wild);

unsigned int	_p_mysql_num_fields(MYSQL_RES *res);
long long	_p_mysql_num_rows(MYSQL_RES *res);

/* char *		_p_mysql_odbc_escape_string(MYSQL *m, char *to, unsigned long to_length,
											const char *from, unsigned long from_length, void *param,
											char *(*extended_buffer)(void*, char*to, unsigned long *length));
*/

int 			_p_mysql_options(MYSQL *m, /*enum mysql_option option*/ int option, const char *arg);
int				_p_mysql_ping(MYSQL *m);

int				_p_mysql_query(MYSQL *m, const char *query);

MYSQL * 	_p_mysql_real_connect(MYSQL *m, const char *host,
			const char *user, const char *passwd, const char *db,
			unsigned int port, const char *socket,	unsigned int client_flag);
MYSQL * 			_p_mysql_real_connect2(MYSQL *m, const char *host,
			const char *user,	const char *passwd, const char *db);
			
unsigned long _p_mysql_real_escape_string(MYSQL *m, char *to, const char *from, unsigned long length);
int						_p_mysql_real_query(MYSQL *m, const char *query,
			unsigned int length);

/* int						_p_mysql_refresh(MYSQL *m, unsigned int refresh_options); */

MYSQL_ROW_OFFSET	_p_mysql_row_seek(MYSQL_RES *res, MYSQL_ROW_OFFSET oset);
MYSQL_ROW_OFFSET	_p_mysql_row_tell(MYSQL_RES *res);

int						_p_mysql_select_db(MYSQL *m, const char *db);
int						_p_mysql_shutdown(MYSQL *m);
char *				_p_mysql_stat(MYSQL *m);
MYSQL_RES *		_p_mysql_store_result(MYSQL *m);

unsigned long	_p_mysql_thread_id(MYSQL *m);
/* unsigned int  _p_mysql_thread_safe(void); */
MYSQL_RES *		_p_mysql_use_result(MYSQL *m);



/* ********** Implementation ******* */

long long _p_mysql_affected_rows(MYSQL *m)
{
	return mysql_affected_rows(m);
}

void _p_mysql_close(MYSQL *m)
{
	mysql_close(m);
}

unsigned char _p_mysql_change_user(MYSQL *m, const char *user, const char *passwd, const char *db)
{
	return (unsigned char) mysql_change_user(m, user, passwd, db);
}

int _p_mysql_create_db(MYSQL *m, const char *db)
{
	return mysql_create_db(m, db);
}

const char*		_p_mysql_character_set_name(MYSQL *m)
{
	return mysql_character_set_name(m);
}

void _p_mysql_data_seek(MYSQL_RES *res, unsigned int offset)
{
	mysql_data_seek(res, offset);
}
void _p_mysql_debug(char *debug)
{
	mysql_debug(debug);
}
int _p_mysql_drop_db(MYSQL *m, const char *db)
{
	return mysql_drop_db(m, db);
}
int _p_mysql_dump_debug_info(MYSQL *m)
{
	return mysql_dump_debug_info(m);
}

unsigned int _p_mysql_errno(MYSQL *m)
{
	return mysql_errno(m);
}

char * _p_mysql_error(MYSQL *m)
{
	return mysql_error(m);
}

unsigned int _p_mysql_escape_string(char *to, const char *from, unsigned int length)
{
	return mysql_escape_string(to, from, length);
}

MYSQL_FIELD *_p_mysql_fetch_field(MYSQL_RES *res)
{
	return mysql_fetch_field(res);
}

MYSQL_FIELD *_p_mysql_fetch_field_direct(MYSQL_RES *res, unsigned int fieldnr)
{
		return mysql_fetch_field_direct(res, fieldnr);
}

/* MYSQL_FIELD *	_p_mysql_fetch_fields(MYSQL_RES *res)
{
	return mysql_fetch_field(res);
}
*/
unsigned long *	_p_mysql_fetch_lengths(MYSQL_RES *res)
{
	return mysql_fetch_lengths(res);
}

MYSQL_ROW _p_mysql_fetch_row(MYSQL_RES *res)
{
	return mysql_fetch_row(res);
}

unsigned int				_p_mysql_field_count(MYSQL *m)
{
	return mysql_field_count(m);
}

MYSQL_FIELD_OFFSET _p_mysql_field_seek(MYSQL_RES *res, MYSQL_FIELD_OFFSET offset)
{
	return mysql_field_seek(res, offset);
}

MYSQL_FIELD_OFFSET _p_mysql_field_tell(MYSQL_RES *res)
{
	return mysql_field_tell(res);
}

void _p_mysql_free_result(MYSQL_RES *res)
{
	mysql_free_result(res);
}


char * _p_mysql_get_client_info(void)
{
	return mysql_get_client_info();
}

char * _p_mysql_get_host_info(MYSQL *m)
{
	return mysql_get_host_info(m);
}

unsigned int _p_mysql_get_proto_info(MYSQL *m)
{
	return mysql_get_proto_info(m);
}

char * _p_mysql_get_server_info(MYSQL *m)
{
	return mysql_get_server_info(m);
}

char * _p_mysql_info(MYSQL *m)
{
	return mysql_info(m);
}

MYSQL *_p_mysql_init(MYSQL *m)
{
	return mysql_init(m);
}

long long _p_mysql_insert_id(MYSQL *m)
{
	return mysql_insert_id(m);
}
 
int _p_mysql_kill(MYSQL *m, unsigned long pid)
{
	return mysql_kill(m, pid);
}

MYSQL_RES *_p_mysql_list_dbs(MYSQL *m, const char *wild)
{
	return mysql_list_dbs(m, wild);
}

MYSQL_RES *_p_mysql_list_fields(MYSQL *m, const char *table, const char *wild)
{
	return mysql_list_fields(m, table, wild);
}

MYSQL_RES *_p_mysql_list_processes(MYSQL *m)
{
	return mysql_list_processes(m);
}

MYSQL_RES *_p_mysql_list_tables(MYSQL *m, const char *wild)
{
	return mysql_list_tables(m, wild);
}

unsigned int	_p_mysql_num_fields(MYSQL_RES *res)
{
	return mysql_num_fields(res);
}

long long _p_mysql_num_rows(MYSQL_RES *res)
{	
	return mysql_num_rows(res);
}

int _p_mysql_options(MYSQL *m, /* enum mysql_option option*/ int option, const char *arg)
{
	return mysql_options(m, option, arg);
}

int _p_mysql_ping(MYSQL *m)
{
	return mysql_ping(m);
}

int _p_mysql_query(MYSQL *m, const char *query)
{
	return mysql_query(m, query);
}

MYSQL * _p_mysql_real_connect(MYSQL *m, const char *host, const char *user,
	const char *passwd, const char *db, unsigned int port, const char *socket,
	unsigned int client_flag)
{
	return mysql_real_connect(m, host, user, passwd, db, port, socket, client_flag);
}
MYSQL * _p_mysql_real_connect2(MYSQL *m, const char *host, const char *user,
	const char *passwd, const char *db)
{
	return mysql_real_connect(m, host, user, passwd, db, 0, NULL, 0);
}

unsigned long _p_mysql_real_escape_string(MYSQL *m, char *to, const char *from, unsigned long length)
{
	return mysql_real_escape_string(m, to, from, length);
}

int _p_mysql_real_query(MYSQL *m, const char *query, unsigned int length)
{
	return mysql_real_query(m, query, length);
}

MYSQL_ROW_OFFSET _p_mysql_row_seek(MYSQL_RES *res, MYSQL_ROW_OFFSET oset)
{
	return mysql_row_seek(res, oset);
}

MYSQL_ROW_OFFSET	_p_mysql_row_tell(MYSQL_RES *res)
{
	return mysql_row_tell(res);
}

int _p_mysql_select_db(MYSQL *m, const char *db)
{
	return mysql_select_db(m, db);
}
int _p_mysql_shutdown(MYSQL *m)
{
	return mysql_shutdown(m);
}
char * _p_mysql_stat(MYSQL *m)
{
	return mysql_stat(m);
}
MYSQL_RES * _p_mysql_store_result(MYSQL *m)
{
	return mysql_store_result(m);
}

unsigned long _p_mysql_thread_id(MYSQL *m)
{
	return mysql_thread_id(m);
}

MYSQL_RES * _p_mysql_use_result(MYSQL *m)
{
	return mysql_use_result(m);
}
